<center>
<img src="https://www.kagsa.org/download/assets/logo.png" >

# 
KAGSA is a new Interpreted programming language based on Python.

<a href="https://github.com/kagsa/kagsa/tree/main/kagsasrc"><img src="https://img.shields.io/github/languages/code-size/kagsa/kagsa?style=flat-square"></a>
<a href="https://www.kagsa.org/download/"><img src="https://img.shields.io/github/downloads/kagsa/kagsa/total?style=flat-square"></a>
<a href="https://github.com/kagsa/kagsa/blob/main/LICENSE"><img src="https://img.shields.io/github/license/kagsa/kagsa?style=flat-square"></a>
<a href="https://www.kagsa.org"><img src="https://img.shields.io/badge/Web-KAGSA.ORG-blue?style=flat-square"></a>
</center>

it designed to be easy to learn and practical for use in various projects. It has a flexible syntax and allows some things that other languages prohibit, such as using certain symbols in variable names and starting variable names with numbers. KAGSA contains several main components, including a lexer, syntax checker, parser, and compiler. It supports object-oriented programming, iteration, and other features commonly used in programming languages.

# Installation

You can download it via Python pip, launch the command prompt and run the following command:
```
pip install kagsa
```
KAGSA is also available for **Windows, Linux and Termux**, any version can be downloaded from the [official website](https://www.kagsa.org/download/)

There is a document explaining the installation method, you can read it [Here](https://www.kagsa.org/download/help.html)

# Getting Started

Once you have installed KAGSA, you can start writing and running KAGSA programs. Here are the basic steps:
-    Create a new text file with a .kg extension.
-    Open the file in a text editor and write your KAGSA code.
-    Save the file.
-    Open a terminal or command prompt and navigate to the directory where the file is saved.
-    Type the following command and press Enter:

```
kagsa filename.kg
```
-    Replace `filename` with the name of your file.

-    Your KAGSA program should now run in the terminal.

# Documentation

Full documentation for KAGSA can be found in the [KAGSA.ORG/DOCS](https://www.kagsa.org/docs/index.html).

# Examples

KAGSA supports features such as object-oriented programming and iteration. Here are some example programs:

-    [Hello World](https://github.com/kagsa/kagsa/blob/main/examples/helloworld.kg)
-    [Object-Oriented Programming](https://github.com/kagsa/kagsa/blob/main/examples/oop.kg)
-    [Factorial](https://github.com/kagsa/kagsa/blob/main/examples/factorial.kg)
-    [FizzBuzz](https://github.com/kagsa/kagsa/blob/main/examples/fizzbuzz.kg)
-    [Palindrome Checker](https://github.com/kagsa/kagsa/blob/main/examples/palindrome.kg)
-    [Binary Search](https://github.com/kagsa/kagsa/blob/main/examples/binsearch.kg)
-    [Error Handling](https://github.com/kagsa/kagsa/blob/main/examples/errors.kg)

And more you can find it at [KAGSA/KAGSA/examples](https://github.com/kagsa/kagsa/tree/main/examples).